pub async fn soft_delete(conn: &mut PgConnection, id: Uuid) -> ModelResult<()>Expand description
Lets a rate-cap override or an admin resend mail the same address again.
pub async fn soft_delete(conn: &mut PgConnection, id: Uuid) -> ModelResult<()>Lets a rate-cap override or an admin resend mail the same address again.