pub async fn soft_delete_batch(
conn: &mut PgConnection,
ids: &[Uuid],
) -> ModelResult<()>Expand description
Batch form of soft_delete: one UPDATE for every row instead of one per id.
pub async fn soft_delete_batch(
conn: &mut PgConnection,
ids: &[Uuid],
) -> ModelResult<()>Batch form of soft_delete: one UPDATE for every row instead of one per id.