pub struct ExistingLinkingMailFact {
pub sisu_person_id: String,
pub course_id: Uuid,
pub emailed_to: String,
pub sent_at: DateTime<Utc>,
}Expand description
As much of one existing mail as the dedup guard and the rate caps need to decide on a person.
Fields
sisu_person_id: Stringcourse_id: Uuidemailed_to: Stringsent_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ExistingLinkingMailFact
impl Clone for ExistingLinkingMailFact
Sourcefn clone(&self) -> ExistingLinkingMailFact
fn clone(&self) -> ExistingLinkingMailFact
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExistingLinkingMailFact
impl Debug for ExistingLinkingMailFact
Sourceimpl PartialEq for ExistingLinkingMailFact
impl PartialEq for ExistingLinkingMailFact
impl StructuralPartialEq for ExistingLinkingMailFact