pub async fn set_email_delivery_id(
conn: &mut PgConnection,
id: Uuid,
email_delivery_id: Uuid,
) -> ModelResult<()>Expand description
Records which delivery carries this mail, which is also what takes the slot out of the queue.
pub async fn set_email_delivery_id(
conn: &mut PgConnection,
id: Uuid,
email_delivery_id: Uuid,
) -> ModelResult<()>Records which delivery carries this mail, which is also what takes the slot out of the queue.